/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.disttest.client;

import java.util.Collection;
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

public class ParticipantExecutorRegistry
{
    private final Set<ParticipantExecutor> _participantExecutors = Collections.synchronizedSet(new HashSet<>());

    public void add(ParticipantExecutor participantExecutor)
    {
        _participantExecutors.add(participantExecutor);
    }

    public void clear()
    {
        _participantExecutors.clear();
    }

    public Collection<ParticipantExecutor> executors()
    {
        return Collections.unmodifiableSet(_participantExecutors);
    }
}
